==> apache-inlong-0.12.0-incubating-src.tar.gz: apache-inlong-0.12.0-incubating/inlong-manager/manager-common/src/main/java/org/apache/inlong/manager/common/pojo/workflow/WorkflowApproverQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.common.pojo.workflow;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * Workflow Approver Query Condition
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@ApiModel("Workflow Approver Query Condition")
public class WorkflowApproverQuery {

    @ApiModelProperty("id")
    private Integer id;

    @ApiModelProperty("Process definition name")
    private String processName;

    @ApiModelProperty("Approval task name")
    private String taskName;

    @ApiModelProperty("Filter Condition KEY")
    private String filterKey;

    @ApiModelProperty("Filter matching values")
    private String filterValue;

    @ApiModelProperty("Approver")
    private String approver;

    private String creator;

    private String modifier;
}

==> apache-inlong-1.1.0-incubating-src.tar.gz: apache-inlong-1.1.0-incubating/inlong-manager/manager-common/src/main/java/org/apache/inlong/manager/common/pojo/workflow/WorkflowApproverQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.common.pojo.workflow;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * Workflow Approver Query Condition
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@ApiModel("Workflow Approver Query Condition")
public class WorkflowApproverQuery {

    @ApiModelProperty("id")
    private Integer id;

    @ApiModelProperty("WorkflowProcess definition name")
    private String processName;

    @ApiModelProperty("Approval task name")
    private String taskName;

    @ApiModelProperty("Filter Condition KEY")
    private String filterKey;

    @ApiModelProperty("Filter matching values")
    private String filterValue;

    @ApiModelProperty("Approver")
    private String approver;

    private String creator;

    private String modifier;
}
